/*
 * Filesystem IPC client interface.
 *
 * Copyright (C) 2018, 2019, 2020 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <sys/stat.h>

#include <fsclient/fsdesc.h>
#include <systypes/user.h>

EXTERN_C_BEGIN

/* Filesystem configuration methods. */

long fs_getuserfs(l4_cap_idx_t server, user_t user, l4_cap_idx_t *ref);

/* Filesystem access methods. */

long fs_context(file_descriptor_t *desc);
long fs_context_getfs(file_descriptor_t *desc);
long fs_context_mount(file_descriptor_t *desc);
long fs_context_open(file_descriptor_t *desc, int flags);

/* Filesystem object access methods. */

long fs_begin(file_descriptor_t *desc);
long fs_begin_first(file_descriptor_t *desc);
long fs_end(file_descriptor_t *desc);
long fs_flush(file_descriptor_t *desc);
long fs_fstat(file_descriptor_t *desc, struct stat *statbuf);
long fs_mmap(file_descriptor_t *desc, off_t position, size_t length);
long fs_yield(file_descriptor_t *desc);

/* Pipe opener methods. */

long fs_pipe(l4_cap_idx_t server, file_descriptor_t *reader, file_descriptor_t *writer);

/* Pipe access methods. */

long fs_current_region(file_descriptor_t *desc);
long fs_next_region(file_descriptor_t *desc);

EXTERN_C_END
